@@ -8,6 +8,7 @@ from .v3.cert_auth import CertAuth
 from .v3.device_resources import DeviceResources
 from .v3.device_tests import DeviceTests
 from .v3.devices import Devices
+from .v3.device_events import DeviceEvents
 from .v3.dialects import Dialects
 from .v3.domains import Domains
 from .v3.data_model import DataModel
@@ -49,19 +50,25 @@ class Coiote:
         self.authenticator = Authenticator(
             self.url, self.session, auth=auth)
 
-        self.aws_integration: AwsIntegration = self._make_module(AwsIntegration)
-        self.assigned_device_properties: AssignedDeviceProperties = self._make_module(AssignedDeviceProperties)
+        self.aws_integration: AwsIntegration = self._make_module(
+            AwsIntegration)
+        self.assigned_device_properties: AssignedDeviceProperties = self._make_module(
+            AssignedDeviceProperties)
         self.cert_auth: CertAuth = self._make_module(CertAuth)
         self.data_model: DataModel = self._make_module(DataModel)
-        self.device_monitoring: DeviceMonitoring = self._make_module(DeviceMonitoring)
-        self.device_resources: DeviceResources = self._make_module(DeviceResources)
+        self.device_monitoring: DeviceMonitoring = self._make_module(
+            DeviceMonitoring)
+        self.device_resources: DeviceResources = self._make_module(
+            DeviceResources)
         self.device_tests: DeviceTests = self._make_module(DeviceTests)
         self.devices: Devices = self._make_module(Devices)
         self.dialects: Dialects = self._make_module(Dialects)
+        self.device_events: DeviceEvents = self._make_module(DeviceEvents)
         self.domains: Domains = self._make_module(Domains)
         self.extensions: Extensions = self._make_module(Extensions)
         self.groups: Groups = self._make_module(Groups)
-        self.lifecycle_management: LifecycleManagement = self._make_module(LifecycleManagement)
+        self.lifecycle_management: LifecycleManagement = self._make_module(
+            LifecycleManagement)
         self.observations: Observations = self._make_module(Observations)
         self.resources: Resources = self._make_module(Resources)
         self.sessions: Sessions = self._make_module(Sessions)
