@@ -55,7 +55,13 @@ class Token:
     type: str = "token"
 
 
-WebhookAuth = Union[BasicAuth, Token]
+@dataclass
+class CustomAuth:
+    value: str
+    type: str = "customAuth"
+
+
+WebhookAuth = Union[BasicAuth, Token, CustomAuth]
 
 
 class WebhookFormat(str, AutoNamedEnum):
@@ -69,11 +75,23 @@ class WebhookMethod(str, AutoNamedEnum):
     Patch = "patch"
 
 
+class ContentType(str, AutoNamedEnum):
+    Text = "text"
+    Json = "json"
+
+
+@dataclass
+class BodyTemplate:
+    contentType: ContentType
+    value: str
+
+
 @dataclass
 class WebhookConnectionConfig:
     uri: str
     auth: Optional[WebhookAuth] = None
     additionalHeaders: Dict[str, str] = field(default_factory=dict)
+    bodyTemplate: Optional[BodyTemplate] = None
     format: Optional[WebhookFormat] = None
     method: Optional[WebhookMethod] = WebhookMethod.Post
 
@@ -82,6 +100,7 @@ class WebhookConnectionConfig:
 class KafkaFromPropertiesConnectionConfig:
     topic: str
     headers: Dict[str, str] = field(default_factory=dict)
+    bodyTemplate: Optional[BodyTemplate] = None
     type: str = "domainProperty"
 
 
@@ -90,6 +109,7 @@ class CustomKafkaConnectionConfig:
     value: str
     topic: str
     headers: Dict[str, str] = field(default_factory=dict)
+    bodyTemplate: Optional[BodyTemplate] = None
     type: str = "custom"
 
 
